@@ -39,6 +39,7 @@
 #include <gedit/gedit-utils.h>
 #include <gedit/gedit-window.h>
 
+#include <gedit/gseal-gtk-compat.h>
 
 /* Properties */
 enum 
@@ -137,7 +138,7 @@ set_logout_mode (GeditCloseConfirmationDialog *dlg,
 	if (logout_mode)
 	{
 		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       _("Logout _without Saving"),
+				       _("Log Out _without Saving"),
 				       GTK_RESPONSE_NO);
 
 		gedit_dialog_add_button (GTK_DIALOG (dlg),
@@ -196,7 +197,8 @@ gedit_close_confirmation_dialog_init (GeditCloseConfirmationDialog *dlg)
 			& GEDIT_LOCKDOWN_SAVE_TO_DISK;
 
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);		
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 14);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+			     14);
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	gtk_window_set_skip_taskbar_hint (GTK_WINDOW (dlg), TRUE);
@@ -507,6 +509,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0.0, 0.5);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
+	gtk_widget_set_can_focus (primary_label, FALSE);
 
 	doc_name = gedit_document_get_short_name_for_display (doc);
 
@@ -539,6 +542,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (secondary_label), 0.0, 0.5);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
+	gtk_widget_set_can_focus (secondary_label, FALSE);
 
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
@@ -553,7 +557,7 @@ build_single_doc_dialog (GeditCloseConfirmationDialog *dlg)
 		      
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, FALSE, FALSE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), 
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			    hbox, 
 	                    FALSE, 
 			    FALSE, 
@@ -676,7 +680,7 @@ build_multiple_docs_dialog (GeditCloseConfirmationDialog *dlg)
 
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-  	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), 
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
 			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
@@ -787,3 +791,4 @@ gedit_close_confirmation_dialog_get_unsaved_documents (GeditCloseConfirmationDia
 
 	return dlg->priv->unsaved_documents;
 }
+/* ex:ts=8:noet: */
