@@ -568,7 +568,7 @@ setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 	gedit_debug (DEBUG_PREFS);
 
 	gtk_widget_set_tooltip_text (dlg->priv->font_button,
-			 _("Push this button to select the font to be used by the editor"));
+			 _("Click on this button to select the font to be used by the editor"));
 
 	gedit_utils_set_atk_relation (dlg->priv->font_button,
 				      dlg->priv->default_font_checkbutton,
@@ -1145,8 +1145,9 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 	{
 		gtk_widget_show (error_widget);
 			
-		gtk_box_pack_start_defaults (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
-					     error_widget);
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
+		                    error_widget,
+		                    TRUE, TRUE, 0);
 		
 		return;
 	}
@@ -1186,3 +1187,4 @@ gedit_show_preferences_dialog (GeditWindow *parent)
 
 	gtk_window_present (GTK_WINDOW (preferences_dialog));
 }
+/* ex:ts=8:noet: */
