@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-debug.c 4809 2006-04-08 14:46:31Z pborelli $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -47,7 +47,7 @@ static gdouble last = 0.0;
 static GeditDebugSection debug = GEDIT_NO_DEBUG;
 
 void
-gedit_debug_init ()
+gedit_debug_init (void)
 {
 	if (g_getenv ("GEDIT_DEBUG") != NULL)
 	{
@@ -157,3 +157,4 @@ void gedit_debug (GeditDebugSection  section,
 		fflush (stdout);
 	}
 }
+/* ex:ts=8:noet: */
