@@ -126,9 +126,10 @@ struct _GeditDocumentClass
 
 	/* Document load */
 	void (* load)			(GeditDocument       *document,
-					 const gchar         *uri,
+					 GFile               *location,
 					 const GeditEncoding *encoding,
 					 gint                 line_pos,
+					 gint                 column_pos,
 					 gboolean             create);
 
 	void (* loading)		(GeditDocument    *document,
@@ -139,10 +140,11 @@ struct _GeditDocumentClass
 					 const GError     *error);
 
 	/* Document save */
-	void (* save)			(GeditDocument          *document,
-					 const gchar            *uri,
-					 const GeditEncoding    *encoding,
-					 GeditDocumentSaveFlags  flags);
+	void (* save)			(GeditDocument           *document,
+					 GFile                   *location,
+					 const GeditEncoding     *encoding,
+					 GeditDocumentNewlineType newline_type,
+					 GeditDocumentSaveFlags   flags);
 
 	void (* saving)			(GeditDocument    *document,
 					 goffset	   size,
@@ -177,10 +179,8 @@ GType		 gedit_document_get_type      	(void) G_GNUC_CONST;
 GeditDocument   *gedit_document_new 		(void);
 
 GFile		*gedit_document_get_location	(GeditDocument       *doc);
-
-gchar		*gedit_document_get_uri 	(GeditDocument       *doc);
-void		 gedit_document_set_uri		(GeditDocument       *doc,
-						 const gchar 	     *uri);
+void		 gedit_document_set_location	(GeditDocument       *doc,
+						 GFile               *location);
 
 gchar		*gedit_document_get_uri_for_display
 						(GeditDocument       *doc);
@@ -203,25 +203,22 @@ gchar		*gedit_document_get_mime_type 	(GeditDocument       *doc);
 gboolean	 gedit_document_get_readonly 	(GeditDocument       *doc);
 
 void		 gedit_document_load 		(GeditDocument       *doc,
-						 const gchar         *uri,
+						 GFile               *location,
 						 const GeditEncoding *encoding,
 						 gint                 line_pos,
-						 gboolean             create); 
-
-gboolean	 gedit_document_insert_file	(GeditDocument       *doc,
-						 GtkTextIter         *iter, 
-						 const gchar         *uri, 
-						 const GeditEncoding *encoding);
+						 gint                 column_pos,
+						 gboolean             create);
 
 gboolean	 gedit_document_load_cancel	(GeditDocument       *doc);
 
 void		 gedit_document_save 		(GeditDocument       *doc,
 						 GeditDocumentSaveFlags flags);
 
-void		 gedit_document_save_as 	(GeditDocument       *doc,	
-						 const gchar         *uri, 
-						 const GeditEncoding *encoding,
-						 GeditDocumentSaveFlags flags);
+void		 gedit_document_save_as 	(GeditDocument           *doc,	
+						 GFile                   *location, 
+						 const GeditEncoding     *encoding,
+						 GeditDocumentNewlineType newline_type,
+						 GeditDocumentSaveFlags   flags);
 
 gboolean	 gedit_document_is_untouched 	(GeditDocument       *doc);
 gboolean	 gedit_document_is_untitled 	(GeditDocument       *doc);
@@ -279,9 +276,6 @@ void		 gedit_document_set_enable_search_highlighting
 gboolean	 gedit_document_get_enable_search_highlighting
 						(GeditDocument       *doc);
 
-void		 gedit_document_set_newline_type (GeditDocument           *doc,
-						  GeditDocumentNewlineType newline_type);
-
 GeditDocumentNewlineType
 		 gedit_document_get_newline_type (GeditDocument *doc);
 
@@ -336,3 +330,4 @@ GMountOperation
 G_END_DECLS
 
 #endif /* __GEDIT_DOCUMENT_H__ */
+/* ex:ts=8:noet: */
