@@ -107,11 +107,16 @@ create_option_menu (GeditFileChooserDialog *dialog)
 static void
 update_newline_visibility (GeditFileChooserDialog *dialog)
 {
-	gboolean issave = gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) ==
-	                  GTK_FILE_CHOOSER_ACTION_SAVE;
-
-	gtk_widget_set_visible (dialog->priv->newline_label, issave);
-	gtk_widget_set_visible (dialog->priv->newline_combo, issave);
+	if (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE)
+	{
+		gtk_widget_show (dialog->priv->newline_label);
+		gtk_widget_show (dialog->priv->newline_combo);
+	}
+	else
+	{
+		gtk_widget_hide (dialog->priv->newline_label);
+		gtk_widget_hide (dialog->priv->newline_combo);
+	}
 }
 
 static void
@@ -553,3 +558,4 @@ gedit_file_chooser_dialog_get_newline_type (GeditFileChooserDialog *dialog)
 
 	return newline_type;
 }
+/* ex:ts=8:noet: */
