@@ -25,13 +25,13 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-help.h 6353 2008-08-06 19:45:23Z jessevdk $
+ * $Id$
  */
 
 #ifndef __GEDIT_HELP_H__
 #define __GEDIT_HELP_H__
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -42,3 +42,4 @@ gboolean	gedit_help_display (GtkWindow   *parent,
 G_END_DECLS
 
 #endif /* __GEDIT_HELP_H__ */
+/* ex:ts=8:noet: */
