@@ -318,16 +318,6 @@ DEFINE_BOOL_PREF (create_backup_copy,
 		  GPM_CREATE_BACKUP_COPY,
 		  GPM_DEFAULT_CREATE_BACKUP_COPY)
 
-/* Backup extension. This is configurable only using gconftool or gconf-editor */
-gchar *
-gedit_prefs_manager_get_backup_extension (void)
-{
-	gedit_debug (DEBUG_PREFS);
-
-	return gedit_prefs_manager_get_string (GPM_BACKUP_COPY_EXTENSION,	
-					       GPM_DEFAULT_BACKUP_COPY_EXTENSION);
-}
-
 /* Auto save */
 DEFINE_BOOL_PREF (auto_save,
 		  GPM_AUTO_SAVE,
@@ -1139,13 +1129,13 @@ check_type (const gchar* key, GConfValue* val, GConfValueType t, GError** err)
     {
       /*
       gconf_set_error(err, GCONF_ERROR_TYPE_MISMATCH,
-                      _("Expected `%s' got `%s' for key %s"),
+                      _("Expected `%s' got, `%s' for key %s"),
                       gconf_value_type_to_string(t),
                       gconf_value_type_to_string(val->type),
                       key);
       */
       g_set_error (err, GCONF_ERROR, GCONF_ERROR_TYPE_MISMATCH,
-	  	   _("Expected `%s' got `%s' for key %s"),
+	  	   _("Expected `%s', got `%s' for key %s"),
                    gconf_value_type_to_string(t),
                    gconf_value_type_to_string(val->type),
                    key);
@@ -1249,3 +1239,4 @@ gconf_client_get_int_with_default (GConfClient* client, const gchar* key,
     }
 }
 
+/* ex:ts=8:noet: */
