@@ -32,19 +32,18 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-spinner.c,v 1.5 2006/10/19 15:56:44 pborelli Exp $
+ * $Id$
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include "gedit-spinner.h"
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtksettings.h>
+#include <gtk/gtk.h>
+
+#include "gedit-spinner.h"
+#include "gseal-gtk-compat.h"
 
 /* Spinner cache implementation */
 
@@ -86,14 +85,13 @@ typedef struct
 	GtkIconSize  size;
 	gint         width;
 	gint         height;
-	GdkPixbuf   *quiescent_pixbuf;
 	GdkPixbuf  **animation_pixbufs;
 	guint        n_animation_pixbufs;
 } GeditSpinnerImages;
 
 #define LAST_ICON_SIZE			GTK_ICON_SIZE_DIALOG + 1
-#define SPINNER_ICON_NAME		"gnome-spinner"
-#define SPINNER_REST_ICON_NAME		"gnome-spinner-rest"
+#define SPINNER_ICON_NAME		"process-working"
+#define SPINNER_FALLBACK_ICON_NAME	"gnome-spinner"
 #define GEDIT_SPINNER_IMAGES_INVALID	((GeditSpinnerImages *) 0x1)
 
 typedef struct
@@ -164,8 +162,6 @@ gedit_spinner_images_unref (GeditSpinnerImages *images)
 		}
 		g_free (images->animation_pixbufs);
 
-		g_object_unref (images->quiescent_pixbuf);
-
 		g_free (images);
 	}
 }
@@ -244,7 +240,6 @@ gedit_spinner_images_load (GdkScreen *screen,
 			   GtkIconSize icon_size)
 {
 	GeditSpinnerImages *images;
-	GdkPixbuf *rest_pixbuf = NULL;
 	GdkPixbuf *icon_pixbuf, *pixbuf;
 	GtkIconInfo *icon_info = NULL;
 	int grid_width, grid_height, x, y, requested_size, size, isw, ish, n;
@@ -261,45 +256,26 @@ gedit_spinner_images_load (GdkScreen *screen,
  
 	requested_size = MAX (ish, isw);
 
-	/* Load the rest icon */
+	/* Load the animation. The 'rest icon' is the 0th frame */
 	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
-						SPINNER_REST_ICON_NAME,
+						SPINNER_ICON_NAME,
 						requested_size, 0);
 	if (icon_info == NULL)
-	{
-		g_warning ("Throbber rest icon not found");
-		goto loser;
-	}
-
-	size = gtk_icon_info_get_base_size (icon_info);
-	icon = gtk_icon_info_get_filename (icon_info);
-	if (icon == NULL)
-		goto loser;
-
-	rest_pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
-	gtk_icon_info_free (icon_info);
-	icon_info = NULL;
-
-	if (rest_pixbuf == NULL)
-	{
-		g_warning ("Could not load spinner rest icon");
-		goto loser;
-	}
-
-	if (size > requested_size)
-	{
-		rest_pixbuf = scale_to_size (rest_pixbuf, isw, ish);
-	}
-
-	/* Load the animation */
-	icon_info = gtk_icon_theme_lookup_icon (icon_theme,
-						SPINNER_ICON_NAME,
-					        requested_size, 0);
-	if (icon_info == NULL)
 	{
 		g_warning ("Throbber animation not found");
-		goto loser;
- 	}
+
+		/* If the icon naming spec compliant name wasn't found, try the old name */
+		icon_info = gtk_icon_theme_lookup_icon (icon_theme,
+							SPINNER_FALLBACK_ICON_NAME,
+						        requested_size, 0);
+		if (icon_info == NULL)
+		{
+			g_warning ("Throbber fallback animation not found either");
+			goto loser;
+	 	}
+	}
+
+	g_assert (icon_info != NULL);
 
 	size = gtk_icon_info_get_base_size (icon_info);
 	icon = gtk_icon_info_get_filename (icon_info);
@@ -360,16 +336,16 @@ gedit_spinner_images_load (GdkScreen *screen,
  
 	images->size = icon_size;
 	images->width = images->height = requested_size;
-	images->quiescent_pixbuf = rest_pixbuf;
 
 	images->n_animation_pixbufs = n;
 	images->animation_pixbufs = g_new (GdkPixbuf *, n);
 
 	for (l = list; l != NULL; l = l->next)
 	{
+		g_assert (l->data != NULL);
 		images->animation_pixbufs[--n] = l->data;
 	}
-	/* g_assert (n == 0); */
+	g_assert (n == 0);
 
 	g_slist_free (list);
 
@@ -381,10 +357,7 @@ loser:
 	{
 		gtk_icon_info_free (icon_info);
  	}
-	if (rest_pixbuf)
-	{
-		g_object_unref (rest_pixbuf);
-	}
+
 	g_slist_foreach (list, (GFunc) g_object_unref, NULL);
 
 	/* STOP_PROFILER ("loading spinner animation") */
@@ -607,7 +580,7 @@ gedit_spinner_load_images (GeditSpinner *spinner)
 
 		/* STOP_PROFILER ("gedit_spinner_load_images") */
 
-		priv->current_image = 0;
+		priv->current_image = 0; /* 'rest' icon */
 		priv->need_load = FALSE;
 	}
 
@@ -644,7 +617,7 @@ gedit_spinner_init (GeditSpinner *spinner)
 
 	priv = spinner->priv = GEDIT_SPINNER_GET_PRIVATE (spinner);
 
-	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (spinner), GTK_NO_WINDOW);
+	gtk_widget_set_has_window (GTK_WIDGET (spinner), FALSE);
 
 	priv->cache = gedit_spinner_cache_ref ();
 	priv->size = GTK_ICON_SIZE_DIALOG;
@@ -664,8 +637,9 @@ gedit_spinner_expose (GtkWidget      *widget,
 	GdkGC *gc;
 	int x_offset, y_offset, width, height;
 	GdkRectangle pix_area, dest;
+	GtkAllocation allocation;
 
-	if (!GTK_WIDGET_DRAWABLE (spinner))
+	if (!gtk_widget_is_drawable (GTK_WIDGET (spinner)))
 	{
 		return FALSE;
 	}
@@ -682,33 +656,26 @@ gedit_spinner_expose (GtkWidget      *widget,
 		return FALSE;
 	}
 
-	if (priv->spinning &&
-	    images->n_animation_pixbufs > 0)
-	{
-		g_assert (priv->current_image >= 0 &&
-			  priv->current_image < images->n_animation_pixbufs);
+	/* Otherwise |images| will be NULL anyway */
+	g_assert (images->n_animation_pixbufs > 0);
 
-		pixbuf = images->animation_pixbufs[priv->current_image];
-	}
-	else
-	{
-		pixbuf = images->quiescent_pixbuf;
-	}
+	g_assert (priv->current_image >= 0 &&
+		  priv->current_image < images->n_animation_pixbufs);
 
-	if (pixbuf == NULL)
-	{
-		return FALSE;
-	}
+	pixbuf = images->animation_pixbufs[priv->current_image];
+
+	g_assert (pixbuf != NULL);
 
 	width = gdk_pixbuf_get_width (pixbuf);
 	height = gdk_pixbuf_get_height (pixbuf);
 
 	/* Compute the offsets for the image centered on our allocation */
-	x_offset = (widget->allocation.width - width) / 2;
-	y_offset = (widget->allocation.height - height) / 2;
+	gtk_widget_get_allocation (widget, &allocation);
+	x_offset = (allocation.width - width) / 2;
+	y_offset = (allocation.height - height) / 2;
 
-	pix_area.x = x_offset + widget->allocation.x;
-	pix_area.y = y_offset + widget->allocation.y;
+	pix_area.x = x_offset + allocation.x;
+	pix_area.y = y_offset + allocation.y;
 	pix_area.width = width;
 	pix_area.height = height;
 
@@ -717,10 +684,10 @@ gedit_spinner_expose (GtkWidget      *widget,
 		return FALSE;
 	}
 
-	gc = gdk_gc_new (widget->window);
-	gdk_draw_pixbuf (widget->window, gc, pixbuf,
-			 dest.x - x_offset - widget->allocation.x,
-			 dest.y - y_offset - widget->allocation.y,
+	gc = gdk_gc_new (gtk_widget_get_window (widget));
+	gdk_draw_pixbuf (gtk_widget_get_window (widget), gc, pixbuf,
+			 dest.x - x_offset - allocation.x,
+			 dest.y - y_offset - allocation.y,
 			 dest.x, dest.y,
 			 dest.width, dest.height,
 			 GDK_RGB_DITHER_MAX, 0, 0);
@@ -744,7 +711,8 @@ bump_spinner_frame_cb (GeditSpinner *spinner)
 	priv->current_image++;
 	if (priv->current_image >= priv->images->n_animation_pixbufs)
 	{
-		priv->current_image = 0;
+		/* the 0th frame is the 'rest' icon */
+		priv->current_image = MIN (1, priv->images->n_animation_pixbufs);
 	}
 
 	gtk_widget_queue_draw (GTK_WIDGET (spinner));
@@ -770,11 +738,14 @@ gedit_spinner_start (GeditSpinner *spinner)
 			       priv->timer_task == 0 &&
 			       gedit_spinner_load_images (spinner))
 	{
-		priv->current_image = 0;
+		/* the 0th frame is the 'rest' icon */
+		priv->current_image = MIN (1, priv->images->n_animation_pixbufs);
 
-		priv->timer_task = g_timeout_add (priv->timeout,
-						  (GSourceFunc) bump_spinner_frame_cb,
-						  spinner);
+		priv->timer_task = g_timeout_add_full (G_PRIORITY_LOW,
+						       priv->timeout,
+						       (GSourceFunc) bump_spinner_frame_cb,
+						       spinner,
+						       NULL);
 	}
 }
 
@@ -802,6 +773,7 @@ gedit_spinner_stop (GeditSpinner *spinner)
 	GeditSpinnerPrivate *priv = spinner->priv;
 
 	priv->spinning = FALSE;
+	priv->current_image = 0;
 
 	if (priv->timer_task != 0)
 	{
@@ -1018,3 +990,4 @@ gedit_spinner_new (void)
 {
 	return GTK_WIDGET (g_object_new (GEDIT_TYPE_SPINNER, NULL));
 }
+/* ex:ts=8:noet: */
