@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #    Gedit External Tools plugin
 #    Copyright (C) 2005-2006  Steve Frécinaux <steve@istique.net>
+#    Copyright (C) 2010  Per Arneng <per.arneng@anyplanet.com>
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -27,6 +28,8 @@ from capture import *
 from gtk import gdk
 import re
 import gio
+import linkparsing
+import filelookup
 
 class UniqueById:
     __shared_state = WeakKeyDictionary()
@@ -63,33 +66,35 @@ class OutputPanel(UniqueById):
         self['view'].modify_font(pango.FontDescription('Monospace'))
 
         buffer = self['view'].get_buffer()
-        
-        self.normal_tag = buffer.create_tag("normal")
-        
-        self.error_tag = buffer.create_tag("error")
-        self.error_tag.set_property("foreground", "red")
-        
+
+        self.normal_tag = buffer.create_tag('normal')
+
+        self.error_tag = buffer.create_tag('error')
+        self.error_tag.set_property('foreground', 'red')
+
         self.italic_tag = buffer.create_tag('italic')
         self.italic_tag.set_property('style', pango.STYLE_OBLIQUE)
-        
+
         self.bold_tag = buffer.create_tag('bold')
         self.bold_tag.set_property('weight', pango.WEIGHT_BOLD)
-        
+
+        self.invalid_link_tag = buffer.create_tag('invalid_link')
+
         self.link_tag = buffer.create_tag('link')
-        self.link_tag.set_property('underline', pango.UNDERLINE_LOW)
-        
-        self.line_tag = buffer.create_tag('line')
-        
+        self.link_tag.set_property('underline', pango.UNDERLINE_SINGLE)
+
         self.link_cursor = gdk.Cursor(gdk.HAND2)
         self.normal_cursor = gdk.Cursor(gdk.XTERM)
-        
-        self.link_regex = re.compile('((\\./|\\.\\./|/)[^\s:]+|[^\s:]+\\.[^\s:]+)(:([0-9]+))?')
 
         self.process = None
 
+        self.links = []
+
+        self.link_parser = linkparsing.LinkParser()
+        self.file_lookup = filelookup.FileLookup()
+
     def set_process(self, process):
         self.process = process
-        self.cwd = process.cwd
 
     def __getitem__(self, key):
         # Convenience function to get an object from its name
@@ -108,14 +113,15 @@ class OutputPanel(UniqueById):
 
     def clear(self):
         self['view'].get_buffer().set_text("")
-    
+        self.links = []
+
     def visible(self):
         panel = self.window.get_bottom_panel()
         return panel.props.visible and panel.item_is_active(self.panel)
 
     def write(self, text, tag = None):
         buffer = self['view'].get_buffer()
-        
+
         end_iter = buffer.get_end_iter()
         insert = buffer.create_mark(None, end_iter, True)
 
@@ -123,27 +129,29 @@ class OutputPanel(UniqueById):
             buffer.insert(end_iter, text)
         else:
             buffer.insert_with_tags(end_iter, text, tag)
-        
-        for m in self.link_regex.finditer(text):
-            start = buffer.get_iter_at_mark(insert)
-            start.forward_chars(m.start(0))
-            end = start.copy()
-            end.forward_chars(m.end(0))
+
+        # find all links and apply the appropriate tag for them
+        links = self.link_parser.parse(text)
+        for lnk in links:
             
-            filename = m.group(1)
+            insert_iter = buffer.get_iter_at_mark(insert)
+            lnk.start = insert_iter.get_offset() + lnk.start
+            lnk.end = insert_iter.get_offset() + lnk.end
             
-            if (os.path.isabs(filename) and os.path.isfile(filename)) or \
-               (os.path.isfile(os.path.join(self.cwd, filename))):
-                buffer.apply_tag(self.link_tag, start, end)
-                
-                if m.group(4):
-                    start = buffer.get_iter_at_mark(insert)
-                    start.forward_chars(m.start(4))
-                    end = start.copy()
-                    end.forward_chars(m.end(4))
-            
-                    buffer.apply_tag(self.line_tag, start, end)
-        
+            start_iter = buffer.get_iter_at_offset(lnk.start)
+            end_iter = buffer.get_iter_at_offset(lnk.end)
+
+            tag = None
+
+            # if the link points to an existing file then it is a valid link
+            if self.file_lookup.lookup(lnk.path) is not None:
+                self.links.append(lnk)
+                tag = self.link_tag
+            else:
+                tag = self.invalid_link_tag
+
+            buffer.apply_tag(tag, start_iter, end_iter)
+
         buffer.delete_mark(insert)
         gobject.idle_add(self.scroll_to_end)
 
@@ -151,21 +159,18 @@ class OutputPanel(UniqueById):
         panel = self.window.get_bottom_panel()
         panel.show()
         panel.activate_item(self.panel)
-    
-    def update_cursor_style(self, view, x, y):
-        x, y = view.window_to_buffer_coords(gtk.TEXT_WINDOW_TEXT, int(x), int(y))
-        piter = view.get_iter_at_location(x, y)
-        
-        if piter.has_tag(self.link_tag):
+
+    def update_cursor_style(self, view, x, y):       
+        if self.get_link_at_location(view, x, y) is not None:
             cursor = self.link_cursor
         else:
             cursor = self.normal_cursor
 
         view.get_window(gtk.TEXT_WINDOW_TEXT).set_cursor(cursor)
-    
+
     def on_view_motion_notify_event(self, view, event):
         if event.window == view.get_window(gtk.TEXT_WINDOW_TEXT):
-            self.update_cursor_style(view, event.x, event.y)
+            self.update_cursor_style(view, int(event.x), int(event.y))
 
         return False
 
@@ -175,50 +180,44 @@ class OutputPanel(UniqueById):
             self.update_cursor_style(view, x, y)
 
         return False
-    
+
     def idle_grab_focus(self):
         self.window.get_active_view().grab_focus()
         return False
-    
+
+    def get_link_at_location(self, view, x, y):
+        """
+        Get the link under a specified x,y coordinate. If no link exists then
+        None is returned.
+        """
+
+        # get the offset within the buffer from the x,y coordinates
+        buff_x, buff_y = view.window_to_buffer_coords(gtk.TEXT_WINDOW_TEXT, 
+                                                        x, y)
+        iter_at_xy = view.get_iter_at_location(buff_x, buff_y)
+        offset = iter_at_xy.get_offset()
+
+        # find the first link that contains the offset
+        for lnk in self.links:
+            if offset >= lnk.start and offset <= lnk.end:
+                return lnk
+
+        # no link was found at x,y
+        return None
+
     def on_view_button_press_event(self, view, event):
         if event.button != 1 or event.type != gdk.BUTTON_PRESS or \
            event.window != view.get_window(gtk.TEXT_WINDOW_TEXT):
             return False
-        
-        x, y = view.window_to_buffer_coords(gtk.TEXT_WINDOW_TEXT, int(event.x), int(event.y))
-        
-        start = view.get_iter_at_location(x, y)
 
-        if not start.has_tag(self.link_tag):
+        link = self.get_link_at_location(view, int(event.x), int(event.y))
+        if link is None:
             return False
-        
-        end = start.copy()
-        start.backward_to_tag_toggle(self.link_tag)
-        line = start.copy()
-        
-        end.forward_to_tag_toggle(self.link_tag)
-        line.forward_to_tag_toggle(self.line_tag)
 
-        if line.compare(end) < 0:
-            tot = line.copy()
-            tot.backward_char()
-            
-            text = start.get_text(tot)
-            toline = int(line.get_text(end))
-        else:
-            text = start.get_text(end)
-            toline = 0
+        gfile = self.file_lookup.lookup(link.path)
 
-        gfile = None
-        
-        if os.path.isabs(text) and os.path.isfile(text):
-            gfile = gio.File(text)
-        elif os.path.isfile(os.path.join(self.cwd, text)):
-            gfile = gio.File(os.path.join(self.cwd, text))
-            
         if gfile:
-            gedit.commands.load_uri(self.window, gfile.get_uri(), None, toline)
-            
+            gedit.commands.load_location(self.window, gfile, None, link.line_nr, -1)
             gobject.idle_add(self.idle_grab_focus)
 
 # ex:ts=4:et:
