@@ -18,9 +18,9 @@ register_gedit_file_browser_store_column (GTypeModule *module)
 		{ GEDIT_FILE_BROWSER_STORE_COLUMN_NAME,
 		  "GEDIT_FILE_BROWSER_STORE_COLUMN_NAME",
 		  "name" },
-		{ GEDIT_FILE_BROWSER_STORE_COLUMN_URI,
-		  "GEDIT_FILE_BROWSER_STORE_COLUMN_URI",
-		  "uri" },
+		{ GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
+		  "GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION",
+		  "location" },
 		{ GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS,
 		  "GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS",
 		  "flags" },
