@@ -1,3 +1,23 @@
+/*
+ * gedit-file-browser-messages.c
+ * 
+ * Copyright (C) 2006 - Jesse van den Kieboom <jesse@icecrew.nl>
+ * 
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2, or (at your option)
+ * any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
+
 #include "gedit-file-browser-messages.h"
 #include "gedit-file-browser-store.h"
 #include <gedit/gedit-message.h>
@@ -9,7 +29,7 @@
 
 typedef struct
 {
-	GeditWindow *window;	
+	GeditWindow  *window;	
 	GeditMessage *message;
 } MessageCacheData;
 
@@ -35,7 +55,7 @@ typedef struct
 {
 	gulong id;
 	
-	GeditWindow *window;
+	GeditWindow  *window;
 	GeditMessage *message;
 } FilterData;
 
@@ -73,7 +93,7 @@ window_data_new (GeditWindow            *window,
 }
 
 static WindowData *
-get_window_data (GeditWindow * window)
+get_window_data (GeditWindow *window)
 {
 	return (WindowData *) (g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY));
 }
@@ -161,8 +181,8 @@ message_cache_data_free (MessageCacheData *data)
 }
 
 static MessageCacheData *
-message_cache_data_new (GeditWindow            *window,
-			GeditMessage           *message)
+message_cache_data_new (GeditWindow  *window,
+			GeditMessage *message)
 {
 	MessageCacheData *data = g_slice_new (MessageCacheData);
 	
@@ -178,13 +198,16 @@ message_get_root_cb (GeditMessageBus *bus,
 		     WindowData      *data)
 {
 	GeditFileBrowserStore *store;
-	gchar *uri;
+	GFile *location;
 	
 	store = gedit_file_browser_widget_get_browser_store (data->widget);
-	uri = gedit_file_browser_store_get_virtual_root (store);
-	
-	gedit_message_set (message, "uri", uri, NULL);
-	g_free (uri);
+	location = gedit_file_browser_store_get_virtual_root (store);
+
+	if (location)
+	{
+		gedit_message_set (message, "location", location, NULL);
+		g_object_unref (location);
+	}
 }
 
 static void
@@ -192,10 +215,10 @@ message_set_root_cb (GeditMessageBus *bus,
 		     GeditMessage    *message,
 		     WindowData      *data)
 {
-	gchar *root = NULL;
-	gchar *virtual = NULL;
+	GFile *root;
+	GFile *virtual = NULL;
 	
-	gedit_message_get (message, "uri", &root, NULL);
+	gedit_message_get (message, "location", &root, NULL);
 	
 	if (!root)
 		return;
@@ -207,9 +230,6 @@ message_set_root_cb (GeditMessageBus *bus,
 		gedit_file_browser_widget_set_root_and_virtual_root (data->widget, root, virtual);
 	else
 		gedit_file_browser_widget_set_root (data->widget, root, TRUE);
-	
-	g_free (root);
-	g_free (virtual);
 }
 
 static void
@@ -278,23 +298,30 @@ message_set_emblem_cb (GeditMessageBus *bus,
 
 static gchar *
 item_id (const gchar *path,
-	 const gchar *uri)
+	 GFile *location)
 {
-	return g_strconcat (path, "::", uri, NULL);
+	gchar *uri;
+	gchar *id;
+
+	uri = g_file_get_uri (location);
+	id = g_strconcat (path, "::", uri, NULL);
+	g_free (uri);
+
+	return id;
 }
 
 static gchar *
 track_row (WindowData            *data,
 	   GeditFileBrowserStore *store,
 	   GtkTreePath           *path,
-	   const gchar		 *uri)
+	   GFile		 *location)
 {
 	GtkTreeRowReference *ref;
 	gchar *id;
 	gchar *pathstr;
 	
 	pathstr = gtk_tree_path_to_string (path);
-	id = item_id (pathstr, uri);
+	id = item_id (pathstr, location);
 	
 	ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (store), path);
 	g_hash_table_insert (data->row_tracking, g_strdup (id), ref);
@@ -311,38 +338,35 @@ set_item_message (WindowData   *data,
 		  GeditMessage *message)
 {
 	GeditFileBrowserStore *store;
-	gchar *uri = NULL;
+	GFile *location;
 	guint flags = 0;
 	gchar *track_id;
 	
 	store = gedit_file_browser_widget_get_browser_store (data->widget);
 	
 	gtk_tree_model_get (GTK_TREE_MODEL (store), iter,
-			    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, &uri,
+			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 	
-	if (!uri)
+	if (!location)
 		return;
 
 	if (path && gtk_tree_path_get_depth (path) != 0)
-		track_id = track_row (data, store, path, uri);
+		track_id = track_row (data, store, path, location);
 	else
 		track_id = NULL;
 
 	gedit_message_set (message,
 			   "id", track_id,
-			   "uri", uri,
+			   "location", location,
 			   NULL);
 	
 	if (gedit_message_has_key (message, "is_directory"))
-	{
 		gedit_message_set (message, 
 				   "is_directory", FILE_IS_DIR (flags),
 				   NULL);
-	}			   
 
-	g_free (uri);
 	g_free (track_id);
 }
 
@@ -353,19 +377,18 @@ custom_message_filter_func (GeditFileBrowserWidget *widget,
 			    FilterData             *data)
 {
 	WindowData *wdata = get_window_data (data->window);
-	gchar *uri = NULL;
+	GFile *location;
 	guint flags = 0;
 	gboolean filter = FALSE;
 	GtkTreePath *path;
 	
 	gtk_tree_model_get (GTK_TREE_MODEL (store), iter, 
-			    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, &uri,
+			    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION, &location,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 	
-	if (!uri || FILE_IS_DUMMY (flags))
+	if (!location || FILE_IS_DUMMY (flags))
 	{
-		g_free (uri);
 		return FALSE;
 	}
 	
@@ -399,7 +422,7 @@ message_add_filter_cb (GeditMessageBus *bus,
 			   "method", &method,
 			   NULL);
 	
-	// Check if there exists such a 'callback' message
+	/* Check if there exists such a 'callback' message */
 	if (!object_path || !method)
 	{
 		g_free (object_path);
@@ -418,23 +441,21 @@ message_add_filter_cb (GeditMessageBus *bus,
 		return;
 	}
 	
-	// Check if the message type has the correct arguments
+	/* Check if the message type has the correct arguments */
 	if (gedit_message_type_lookup (message_type, "id") != G_TYPE_STRING ||
-	    gedit_message_type_lookup (message_type, "uri") != G_TYPE_STRING ||
+	    gedit_message_type_lookup (message_type, "location") != G_TYPE_FILE ||
 	    gedit_message_type_lookup (message_type, "is_directory") != G_TYPE_BOOLEAN ||
 	    gedit_message_type_lookup (message_type, "filter") != G_TYPE_BOOLEAN)
-	{
 		return;
-	}
 	
 	cbmessage = gedit_message_type_instantiate (message_type,
 						    "id", NULL,
-						    "uri", NULL,
+						    "location", NULL,
 						    "is_directory", FALSE,
 						    "filter", FALSE,
 						    NULL);
 
-	// Register the custom filter on the widget
+	/* Register the custom filter on the widget */
 	filter_data = filter_data_new (window, cbmessage);
 	id = gedit_file_browser_widget_add_filter (data->widget, 
 						   (GeditFileBrowserWidgetFilterFunc)custom_message_filter_func,
@@ -577,7 +598,7 @@ message_add_context_item_cb (GeditMessageBus *bus,
 		g_free (path);
 		return;
 	}
-	
+
 	gtk_action_group_add_action (data->merged_actions, action);
 	manager = gedit_file_browser_widget_get_ui_manager (data->widget);
 	name = g_strconcat (gtk_action_get_name (action), "MenuItem", NULL);
@@ -625,6 +646,17 @@ message_remove_context_item_cb (GeditMessageBus *bus,
 	gtk_ui_manager_remove_ui (manager, merge_id);
 }
 
+static void
+message_get_view_cb (GeditMessageBus *bus,
+		     GeditMessage    *message,
+		     WindowData      *data)
+{
+	GeditFileBrowserView *view;
+	view = gedit_file_browser_widget_get_browser_view (data->widget);
+
+	gedit_message_set (message, "view", view, NULL);
+}
+
 static void
 register_methods (GeditWindow            *window,
 		  GeditFileBrowserWidget *widget)
@@ -636,13 +668,13 @@ register_methods (GeditWindow            *window,
 	gedit_message_bus_register (bus, 
 				    MESSAGE_OBJECT_PATH, "get_root", 
 				    1,
-				    "uri", G_TYPE_STRING,
+				    "location", G_TYPE_FILE,
 				    NULL);
  
 	gedit_message_bus_register (bus, 
 				    MESSAGE_OBJECT_PATH, "set_root", 
 				    1, 
-				    "uri", G_TYPE_STRING,
+				    "location", G_TYPE_FILE,
 				    "virtual", G_TYPE_STRING,
 				    NULL);
 				    
@@ -702,6 +734,12 @@ register_methods (GeditWindow            *window,
 	gedit_message_bus_register (bus, MESSAGE_OBJECT_PATH, "show_bookmarks", 0, NULL);
 	gedit_message_bus_register (bus, MESSAGE_OBJECT_PATH, "show_files", 0, NULL);
 
+	gedit_message_bus_register (bus,
+				    MESSAGE_OBJECT_PATH, "get_view",
+				    1,
+				    "view", GEDIT_TYPE_FILE_BROWSER_VIEW,
+				    NULL);
+
 	BUS_CONNECT (bus, get_root, data);
 	BUS_CONNECT (bus, set_root, data);
 	BUS_CONNECT (bus, set_emblem, data);
@@ -722,6 +760,8 @@ register_methods (GeditWindow            *window,
 	
 	BUS_CONNECT (bus, show_bookmarks, data);
 	BUS_CONNECT (bus, show_files, data);
+
+	BUS_CONNECT (bus, get_view, data);
 }
 
 static void
@@ -730,11 +770,9 @@ store_row_inserted (GeditFileBrowserStore *store,
 		    GtkTreeIter           *iter,
 		    MessageCacheData      *data)
 {
-	gchar *uri = NULL;
 	guint flags = 0;
 
 	gtk_tree_model_get (GTK_TREE_MODEL (store), iter, 
-			    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, &uri,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 	
@@ -745,8 +783,6 @@ store_row_inserted (GeditFileBrowserStore *store,
 		set_item_message (wdata, iter, path, data->message);
 		gedit_message_bus_send_message_sync (wdata->bus, data->message);
 	}
-	
-	g_free (uri);
 }
 
 static void
@@ -755,14 +791,12 @@ store_row_deleted (GeditFileBrowserStore *store,
 		   MessageCacheData      *data)
 {
 	GtkTreeIter iter;
-	gchar *uri = NULL;
 	guint flags = 0;
 	
 	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (store), &iter, path))
 		return;
 	
-	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter, 
-			    GEDIT_FILE_BROWSER_STORE_COLUMN_URI, &uri,
+	gtk_tree_model_get (GTK_TREE_MODEL (store), &iter,
 			    GEDIT_FILE_BROWSER_STORE_COLUMN_FLAGS, &flags,
 			    -1);
 	
@@ -773,8 +807,6 @@ store_row_deleted (GeditFileBrowserStore *store,
 		set_item_message (wdata, &iter, path, data->message);
 		gedit_message_bus_send_message_sync (wdata->bus, data->message);
 	}
-	
-	g_free (uri);
 }
 
 static void
@@ -783,20 +815,20 @@ store_virtual_root_changed (GeditFileBrowserStore *store,
 			    MessageCacheData      *data)
 {
 	WindowData *wdata = get_window_data (data->window);
-	gchar *uri;
+	GFile *vroot;
 	
-	uri = gedit_file_browser_store_get_virtual_root (store);
+	vroot = gedit_file_browser_store_get_virtual_root (store);
 	
-	if (!uri)
+	if (!vroot)
 		return;
 	
 	gedit_message_set (data->message,
-			   "uri", uri,
+			   "location", vroot,
 			   NULL);
 			   
 	gedit_message_bus_send_message_sync (wdata->bus, data->message);
 	
-	g_free (uri);
+	g_object_unref (vroot);
 }
 
 static void
@@ -851,28 +883,28 @@ register_signals (GeditWindow            *window,
 				    MESSAGE_OBJECT_PATH, "root_changed",
 				    0,
 				    "id", G_TYPE_STRING,
-				    "uri", G_TYPE_STRING,
+				    "location", G_TYPE_FILE,
 				    NULL);
 	
 	begin_loading_type = gedit_message_bus_register (bus,
 				    MESSAGE_OBJECT_PATH, "begin_loading",
 				    0,
 				    "id", G_TYPE_STRING,
-				    "uri", G_TYPE_STRING,
+				    "location", G_TYPE_FILE,
 				    NULL);
 
 	end_loading_type = gedit_message_bus_register (bus,
 				    MESSAGE_OBJECT_PATH, "end_loading",
 				    0,
 				    "id", G_TYPE_STRING,
-				    "uri", G_TYPE_STRING,
+				    "location", G_TYPE_FILE,
 				    NULL);
 
 	inserted_type = gedit_message_bus_register (bus,
 						    MESSAGE_OBJECT_PATH, "inserted",
 						    0,
 						    "id", G_TYPE_STRING,
-						    "uri", G_TYPE_STRING,
+						    "location", G_TYPE_FILE,
 						    "is_directory", G_TYPE_BOOLEAN,
 						    NULL);
 
@@ -880,7 +912,7 @@ register_signals (GeditWindow            *window,
 						   MESSAGE_OBJECT_PATH, "deleted",
 						   0,
 						   "id", G_TYPE_STRING,
-						   "uri", G_TYPE_STRING,
+						   "location", G_TYPE_FILE,
 						   "is_directory", G_TYPE_BOOLEAN,
 						   NULL);
 
@@ -888,7 +920,7 @@ register_signals (GeditWindow            *window,
 	
 	message = gedit_message_type_instantiate (inserted_type, 
 						  "id", NULL,
-						  "uri", NULL, 
+						  "location", NULL,
 						  "is_directory", FALSE, 
 						  NULL);
 
@@ -904,7 +936,7 @@ register_signals (GeditWindow            *window,
 
 	message = gedit_message_type_instantiate (deleted_type, 
 						  "id", NULL, 
-						  "uri", NULL,
+						  "location", NULL,
 						  "is_directory", FALSE, 
 						  NULL);
 	data->row_deleted_id = 
@@ -917,7 +949,7 @@ register_signals (GeditWindow            *window,
 	
 	message = gedit_message_type_instantiate (root_changed_type,
 						  "id", NULL,
-						  "uri", NULL,
+						  "location", NULL,
 						  NULL);
 	data->root_changed_id = 
 		g_signal_connect_data (store,
@@ -929,8 +961,8 @@ register_signals (GeditWindow            *window,
 
 	message = gedit_message_type_instantiate (begin_loading_type,
 						  "id", NULL,
-						  "uri", NULL,
-						  NULL);	
+						  "location", NULL,
+						  NULL);
 	data->begin_loading_id = 
 		g_signal_connect_data (store,
 				      "begin_loading",
@@ -941,7 +973,7 @@ register_signals (GeditWindow            *window,
 
 	message = gedit_message_type_instantiate (end_loading_type,
 						  "id", NULL,
-						  "uri", NULL,
+						  "location", NULL,
 						  NULL);
 	data->end_loading_id = 
 		g_signal_connect_data (store,
@@ -1012,3 +1044,4 @@ gedit_file_browser_messages_unregister (GeditWindow *window)
 
 	window_data_free (window);
 }
+/* ex:ts=8:noet: */
