@@ -20,7 +20,7 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "gedit-gio-document-loader.h"
+#include "gedit-document-loader.h"
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glib.h>
@@ -200,7 +200,6 @@ test_saver (const gchar              *filename_or_uri,
 	gboolean existed;
 
 	document = create_document (contents);
-	gedit_document_set_newline_type (document, newline_type);
 
 	g_signal_connect (document, "saved", G_CALLBACK (complete_test_error), data);
 
@@ -214,12 +213,12 @@ test_saver (const gchar              *filename_or_uri,
 	test_completed = FALSE;
 
 	file = g_file_new_for_commandline_arg (filename_or_uri);
-	uri = g_file_get_uri (file);
 	existed = g_file_query_exists (file, NULL);
 
 	ensure_mounted (file);
 
-	gedit_document_save_as (document, uri, gedit_encoding_get_utf8 (), save_flags);
+	gedit_document_save_as (document, file, gedit_encoding_get_utf8 (),
+			        newline_type, save_flags);
 
 	while (!test_completed)
 	{
@@ -231,7 +230,6 @@ test_saver (const gchar              *filename_or_uri,
 		g_file_delete (file, NULL, NULL);
 	}
 
-	g_free (uri);
 	g_object_unref (file);
 
 	saver_test_data_free (data);
@@ -733,3 +731,4 @@ int main (int   argc,
 
 	return g_test_run ();
 }
+/* ex:ts=8:noet: */
